@@ -37,14 +37,14 @@ obscureCounts <- function(table,
 
   if (!is.null(minCellCount)) {
     # initialise result_obscured as FALSE
-    table$result_obscured <- "FALSE"
+    table$result_obscured <- FALSE
 
     colNames <- setdiff(colnames(table), c("drug_concept_id", "drug",
                                            "ingredient_concept_id", "ingredient", "result_obscured"))
     checkColNames <- NULL
-    if (grepl("drugDailyDose|drugDaysSupply|drugQuantity", tableName))  {
+    if (grepl("drugDose|drugDaysSupply|drugQuantity", tableName))  {
       checkColNames <- colNames[!grepl("prop_", colNames)]
-    } else if (grepl("drugRoutes|drugSig|drugSourceConcepts|drugTypes", tableName)) {
+    } else if (grepl("drugRoutes|drugSig|drugSourceConcepts|drugTypes|drugExposureDuration|missingValues|diagnostics_summary", tableName)) {
       checkColNames <- c("n_records")
     } else if (grepl("conceptSummary", tableName)) {
       checkColNames <- colNames <- c("n_records")
